pub struct Highlight {
pub field: String,
pub name: String,
pub fragment_number: usize,
pub fragment_size: usize,
pub highlight_markup: bool,
pub pre_tags: String,
pub post_tags: String,
}Expand description
Specifies the number and size of fragments (snippets, summaries) to generate from each specified field to provide a “keyword in context” (KWIC) functionality. With highlight_markup the matching query terms within the fragments can be highlighted with HTML markup.
Fields
field: StringSpecifies the field from which the fragments (snippets, summaries) are created.
name: StringAllows to specifiy multiple highlight result fields from the same source field, leaving the original field intact, Default: if name is empty then field is used instead, i.e the original field is overwritten with the highlight.
fragment_number: usizeIf 0/default then return the full original text without fragmenting.
fragment_size: usizeSpecifies the length of a highlight fragment. The default 0 returns the full original text without truncating, but still with highlighting if highlight_markup is enabled.
highlight_markup: boolif true, the matching query terms within the fragments are highlighted with HTML markup <b>term</b>.
Specifies the markup tags to insert before each highlighted term (e.g. "<b>" or "<em>"). This can be any string, but is most often an HTML or XML tag. Only used when highlight_markup is set to true.
Specifies the markup tags to insert after each highlighted term. (e.g. "</b>" or "</em>"). This can be any string, but is most often an HTML or XML tag. Only used when highlight_markup is set to true.